summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/usr/runtime/populate_hbruntime.C7
1 files changed, 6 insertions, 1 deletions
diff --git a/src/usr/runtime/populate_hbruntime.C b/src/usr/runtime/populate_hbruntime.C
index 813620ddd..4093abfc5 100644
--- a/src/usr/runtime/populate_hbruntime.C
+++ b/src/usr/runtime/populate_hbruntime.C
@@ -914,10 +914,15 @@ errlHndl_t fill_RsvMem_hbData(uint64_t & io_start_address,
l_elog->collectTrace(RUNTIME_COMP_NAME);
break;
}
+ // break out of for-loop if
+ if(l_elog)
+ {
+ break;
+ }
i++;
}
// exit if we hit an error
if(l_elog)
{
break;
@@ -914,10 +914,15 @@ errlHndl_t fill_RsvMem_hbData(uint64_t & io_start_address,
i++;
}
- // exit if we hit an error
+ // break out of do-while if we hit an error
if(l_elog)
{
OpenPOWER on IntegriCloud